@@ -1,6 +1,5 @@
 
 /***************************************************************************
- *   ktprint.cpp                                                           *
  *   --------------------------------------------------------------------  *
  *   KDE\QT printing implementation.                                       *
  *   --------------------------------------------------------------------  *
@@ -17,6 +16,7 @@
 #include <qpaintdevicemetrics.h>
 
 #include <ktprintopt.h>
+#include <klocale.h>
 #include "ktprint.h"
 
 const int KTPrint::alignTextLeft             (1000);
@@ -78,7 +78,7 @@ bool KTPrint:: start ()
   prnt->setDocName("Cron Tab");
   prnt->addDialogPage(new KTPrintOpt(root));
 
-  if (prnt->setup()) { //Setup a printer
+  if (prnt->setup(0L, i18n("Print Cron Tab"))) { //Setup a printer
     if (paint!=NULL) delete paint;
     paint = new  QPainter ();
     paint->begin(prnt);
@@ -104,7 +104,7 @@ QFont KTPrint :: getFont () const
   return paint->font();	
 }
 
-void KTPrint :: print (QString str, int col, int alignment, bool wordWrap)
+void KTPrint :: print (const QString &str, int col, int alignment, bool wordWrap)
 {
 //Prints the string str into the column col using
 //the remaining arguments as format flags
