@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -32,7 +32,7 @@ Options::Options()
     _defaultTapeSize   = _config->readNumEntry( "defaultTapeSize", 2*1024*1024 );
     _tapeBlockSize     = _config->readNumEntry( "tapeBlockSize", 20*512 );  // Use tar default.
     _tapeDevice        = _config->readEntry( "tapeDevice", "/dev/tape" ).copy();
-    _tarCommand        = _config->readEntry( "tarCommand", "tar" ).copy();
+    _tarCommand        = _config->readPathEntry( "tarCommand", "tar" ).copy();
     _loadOnMount       = _config->readNumEntry( "loadOnMount", FALSE );
     _lockOnMount       = _config->readNumEntry( "lockOnMount", FALSE );
     _ejectOnUnmount    = _config->readNumEntry( "ejectOnUnmount", FALSE );
@@ -123,7 +123,7 @@ void Options::setTarCommand( const QString & str )
 {
     if ( getTarCommand() != str ) {
         _tarCommand = str;
-        _config->writeEntry( "tarCommand", _tarCommand );
+        _config->writePathEntry( "tarCommand", _tarCommand );
         emit sigTarCommand();
     }
 }
