@@ -30,7 +30,7 @@
 #include <kapplication.h>
 
 #include "IndexDlg.h"
-#include "KDat.h"
+#include "KDatMainWindow.h"
 #include "Options.h"
 #include "Tape.h"
 #include "TapeDrive.h"
@@ -73,13 +73,13 @@ void Tape::format()
 {
     // Rewind tape.
     if ( !TapeDrive::instance()->rewind() ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Rewinding tape failed." ), i18n("Format Failed"));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Rewinding tape failed." ), i18n("Format Failed"));
         return;
     }
 
     // Set block size for tape.
     if ( !TapeDrive::instance()->setBlockSize( Options::instance()->getTapeBlockSize() ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Cannot set tape block size." ), i18n("Format Failed"));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Cannot set tape block size." ), i18n("Format Failed"));
         return;
     }
 
@@ -88,25 +88,25 @@ void Tape::format()
 
     // KDat magic string.
     if ( TapeDrive::instance()->write( KDAT_MAGIC, KDAT_MAGIC_LENGTH ) < KDAT_MAGIC_LENGTH ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Writing magic string failed." ), i18n("Format Failed"));
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Writing magic string failed." ), i18n("Format Failed"));
         return;
     }
 
     // Tape header version number.
     iv = KDAT_TAPE_HEADER_VERSION;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Writing version number failed." ), i18n("Format Failed") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Writing version number failed." ), i18n("Format Failed") );
         return;
     }
 
     // Write tape ID.  Tape ID is machine name + current time.
     iv = _id.length() + 1;
     if ( TapeDrive::instance()->write( (const char*)&iv, 4 ) < 4 ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Writing tape ID length failed." ), i18n("Format Failed") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Writing tape ID length failed." ), i18n("Format Failed") );
         return;
     }
     if ( TapeDrive::instance()->write( _id, iv ) < iv ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Writing tape ID failed." ), i18n("Format Failed") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Writing tape ID failed." ), i18n("Format Failed") );
         return;
     }
 
@@ -150,7 +150,7 @@ void Tape::read()
 
     if ( !_fptr ) {
         // No tape index file was found.
-        int result = KMessageBox::warningContinueCancel( KDat::getInstance(), 
+        int result = KMessageBox::warningContinueCancel( KDatMainWindow::getInstance(), 
                  i18n( "No index file was found for this tape.\n"
                        "Recreate the index from tape?" ), 
                  i18n("Tape Index"), 
@@ -158,7 +158,7 @@ void Tape::read()
         if (result == KMessageBox::Continue ) {
             write();
 
-            IndexDlg dlg( this, KDat::getInstance() );
+            IndexDlg dlg( this, KDatMainWindow::getInstance() );
             dlg.exec();
             TapeManager::instance()->addTape( this );
             return;
@@ -174,7 +174,7 @@ void Tape::read()
     // Read index file version number.
     if ( !fgets( buf, 4096, _fptr ) ) {
         fclose( _fptr );
-        KMessageBox::error( KDat::getInstance(), 
+        KMessageBox::error( KDatMainWindow::getInstance(), 
                               i18n( "Reading version number failed." ), 
                               i18n("Index File Error") );
         return;
@@ -215,7 +215,7 @@ void Tape::read()
 
         default:
         {
-            KMessageBox::sorry( KDat::getInstance(), 
+            KMessageBox::sorry( KDatMainWindow::getInstance(), 
                 i18n( "The tape index file format is version %d. The index cannot be read by this version of KDat. Perhaps the tape index file was created by a newer version of KDat?" ).arg(version ),
                 i18n("Tape Index") );
         }
@@ -631,33 +631,33 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID !=_id ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
 
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
         return;
     }
     _ctime = atoi( buf );
 
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
         return;
     }
     _mtime = atoi( buf );
 
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
         return;
     }
     _name = buf;
@@ -665,14 +665,14 @@ void Tape::readVersion1Index( FILE* fptr )
 
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
         return;
     }
     _size = atoi( buf );
 
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
         return;
     }
     int numArchives = atoi( buf );
@@ -680,7 +680,7 @@ void Tape::readVersion1Index( FILE* fptr )
     for ( ; numArchives; numArchives-- ) {
         // Read archive name.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive name failed." ), i18n("Index File Error") );
+            KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive name failed." ), i18n("Index File Error") );
             return;
         }
         QString archiveName = buf;
@@ -688,21 +688,21 @@ void Tape::readVersion1Index( FILE* fptr )
 
         // Read archive time stamp.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive time stamp failed." ), i18n("Index File Error") );
+            KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive time stamp failed." ), i18n("Index File Error") );
             return;
         }
         int archiveTimeStamp = atoi( buf );
 
         // Read archive start block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive start block failed." ), i18n("Index File Error") );
+            KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive start block failed." ), i18n("Index File Error") );
             return;
         }
         int archiveStartBlock = atoi( buf );
 
         // Read archive end block.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive end block failed." ), i18n("Index File Error") );
+            KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive end block failed." ), i18n("Index File Error") );
             return;
         }
         int archiveEndBlock = atoi( buf );
@@ -715,7 +715,7 @@ void Tape::readVersion1Index( FILE* fptr )
 
         // Read the number of files.
         if ( !fgets( buf, 4096, fptr ) ) {
-            KMessageBox::error( KDat::getInstance(), i18n( "Reading archive file count failed." ), i18n("Index File Error") );
+            KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive file count failed." ), i18n("Index File Error") );
             return;
         }
         int archiveNumFiles = atoi( buf );
@@ -727,7 +727,7 @@ void Tape::readVersion1Index( FILE* fptr )
         for ( ; archiveNumFiles; archiveNumFiles-- ) {
             // Read file name.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMessageBox::error( KDat::getInstance(), i18n( "Reading file name failed." ), i18n("Index File Error") );
+                KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading file name failed." ), i18n("Index File Error") );
                 return;
             }
             QString fileName = buf;
@@ -735,21 +735,21 @@ void Tape::readVersion1Index( FILE* fptr )
 
             // Read file size.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMessageBox::error( KDat::getInstance(), i18n( "Reading file size failed." ), i18n("Index File Error") );
+                KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading file size failed." ), i18n("Index File Error") );
                 return;
             }
             int fileSize = atoi( buf );
 
             // Read file modification time.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMessageBox::error( KDat::getInstance(), i18n( "Reading file modification time failed." ), i18n("Index File Error") );
+                KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading file modification time failed." ), i18n("Index File Error") );
                 return;
             }
             int fileModTime = atoi( buf );
 
             // Read file record number.
             if ( !fgets( buf, 4096, fptr ) ) {
-                KMessageBox::error( KDat::getInstance(), i18n( "Reading file record number failed." ), i18n("Index File Error") );
+                KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading file record number failed." ), i18n("Index File Error") );
                 return;
             }
             int fileRecord = atoi( buf );
@@ -778,33 +778,33 @@ void Tape::readVersion2Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
 
     // Read creation time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading creation time failed." ), i18n("Index File Error") );
         return;
     }
     _ctime = atoi( buf );
 
     // Read modification time.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading modification time failed." ), i18n("Index File Error") );
         return;
     }
     _mtime = atoi( buf );
 
     // Read tape name.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape name failed." ), i18n("Index File Error") );
         return;
     }
     _name = buf;
@@ -812,14 +812,14 @@ void Tape::readVersion2Index( FILE* fptr )
 
     // Read tape size.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape size failed." ), i18n("Index File Error") );
         return;
     }
     _size = atoi( buf );
 
     // Read number of archives.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading archive count failed." ), i18n("Index File Error") );
         return;
     }
     int numArchives = atoi( buf );
@@ -840,13 +840,13 @@ void Tape::readVersion3Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
 
@@ -883,13 +883,13 @@ void Tape::readVersion4Index( FILE* fptr )
 
     // Read the tapeID.
     if ( !fgets( buf, 4096, fptr ) ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Reading tape ID failed." ), i18n("Index File Error") );
         return;
     }
     QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
-        KMessageBox::error( KDat::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
+        KMessageBox::error( KDatMainWindow::getInstance(), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("Index File Error") );
         return;
     }
 
