@@ -14,8 +14,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 #include "gentooInterface.h"
@@ -85,6 +85,8 @@ Gentoo::Gentoo()
       }
     }
   }
+
+    hasProgram = ifExe("emerge");
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -242,8 +244,7 @@ packageInfo *Gentoo::getPackageInfo(char mode, const QString &name, const QStrin
 //////////////////////////////////////////////////////////////////////////////
 packageInfo *Gentoo::collectInstalledInfo(const QString& name, const QString& category)
 {
-  QDict<QString> *a = new QDict<QString>;
-  a->setAutoDelete(true);
+  QMap<QString, QString> a;
 
   QIODevice* iod(KFilterDev::deviceForFile("/var/db/pkg/"+category+"/"+name+"/environment.bz2","application/x-bzip2", true));
   QString line;
@@ -257,25 +258,25 @@ packageInfo *Gentoo::collectInstalledInfo(const QString& name, const QString& ca
     if (line.startsWith("PN="))
     {
       n = line.mid(3);
-      a->insert("name", new QString(n));
+      a.insert("name", n);
     }
     else if (line.startsWith("PVR="))
     {
       version = line.mid(4);
-      a->insert("version", new QString(version));
+      a.insert("version", version);
     }
     else if (line.startsWith("DESCRIPTION="))
     {
       description = line.mid(12);
-      a->insert("summary", new QString(description));
+      a.insert("summary", description);
     }
-    if (a->count() >= 3)
+    if (a.count() >= 3)
       break;
   }
   delete iod;
-  a->insert("group", new QString(category));
-//  a->insert("file-size", new QString("File-size"));
-//  a->insert("size", new QString("Installed-size"));
+  a.insert("group", category);
+//  a.insert("file-size", "File-size");
+//  a.insert("size", "Installed-size");
 
   packageInfo *i = new packageInfo(a,this);
   i->packageState = packageInfo::INSTALLED;
@@ -286,20 +287,18 @@ packageInfo *Gentoo::collectInstalledInfo(const QString& name, const QString& ca
 //////////////////////////////////////////////////////////////////////////////
 packageInfo *Gentoo::collectUninstalledInfo(const QString& name, const QString& category, const QString& version)
 {
-  QDict<QString> *a = new QDict<QString>;
-  a->setAutoDelete(true);
+  QMap<QString, QString> a;
 
-  a->insert("name", new QString(name));
-  a->insert("group", new QString(category));
-  a->insert("version", new QString(version));
-  a->insert("base", new QString(portageDir+category+"/"+name));
-  a->insert("filename", new QString(name+"-"+version+".ebuild"));
+  a.insert("name", name);
+  a.insert("group", category);
+  a.insert("version", version);
+  a.insert("base", portageDir+category+"/"+name);
+  a.insert("filename", name+"-"+version+".ebuild");
 
   QFile f("/var/cache/edb/dep/"+category+"/"+name+"-"+version);
   if (!f.open(IO_ReadOnly))
   {
     kdDebug() << "Couldn't read: " << name << "-" << version << endl;
-    delete a;
     return 0;
   }
 
@@ -322,7 +321,7 @@ packageInfo *Gentoo::collectUninstalledInfo(const QString& name, const QString&
     stream.readLine();
 
   if (!stream.atEnd())
-    a->insert("summary", new QString(stream.readLine()));
+    a.insert("summary", stream.readLine());
 
   QStringList keywords = QStringList::split(' ', stream.readLine());
 
@@ -344,7 +343,6 @@ packageInfo *Gentoo::collectUninstalledInfo(const QString& name, const QString&
   if (!works)
   {
 //    kdDebug() << name << "-" << version << ": Doesn't contain working arch" << endl;
-    delete a;
     return 0;
   }
 
