@@ -32,11 +32,6 @@ namespace ksv
    */
   const QString& copyrightSymbol ();
 
-  /**
-   * \return the hostname (or "Unknown Host")
-   */
-  QString hostname ();
-
   QStyleSheet* styleSheet ();
 
   const QString& logFileFilter ();
