@@ -14,8 +14,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef _KU_GROUP_H_
@@ -30,6 +30,8 @@
 #include "kuserprefs.h"
 #include "sid.h"
 
+namespace KU {
+
 class KGroup {
 public:
   KGroup();
@@ -143,4 +145,6 @@ protected:
   QString domsid;
 };
 
+}
+
 #endif // _KU_GROUP_H_
