@@ -17,8 +17,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -75,7 +75,7 @@ Details::Details(liloimage *lilo, QWidget *parent, const char *name, WFlags /* f
 	readonly=new QCheckBox(_("Mount root filesystem &read-only"), page);
 	QWhatsThis::add(readonly, _("Mount the root filesystem for this kernel read-only. Since the init scripts normally take care of remounting the root filesystem in read-write mode after running some checks, this should always be turned on.<br>Don't turn this off unless you know what you're doing."));
 
-	unsafe=new QCheckBox(_("Don't check &partition table"), page);
+	unsafe=new QCheckBox(_("Do not check &partition table"), page);
 	QWhatsThis::add(unsafe, _("This turns off some sanity checks while writing the configuration. This should not be used under \"normal\" circumstances, but it can be useful, for example, by providing the capability of booting from a floppy disk, without having a floppy in the drive every time you run lilo.<br>This sets the <i>unsafe</i> keyword in lilo.conf."));
 
 	QHBox *opts=new QHBox(page);
